@@ -473,4 +473,48 @@ f_tip FoursquareComm::addTip(QString venueId,QString tip, QString link)
     return tipresult;
 }
 
+bool FoursquareComm::markAs(QString venueId, QString problem)
+{
+
+    qDebug() << "markAs";
+    QByteArray parameters;
+    parameters.append("problem="+problem);
+    QString a = oa->getUrl("venues/"+venueId+"/flag");
+    QString result = doPost(a,parameters);
+
+    QScriptValue sc;
+    QScriptEngine engine;
+    qDebug() << result;
+    sc = engine.evaluate("(" + result + ")");
+
+    if(sc.property("meta").property("code").toNumber()!=200)
+    {
+        qDebug() << "Error occured";
+        return false;
+    }
+    return true;
+}
+
+bool FoursquareComm::addCheckinComment(QString checkinId, QString comment)
+{
+
+    qDebug() << "addCheckinComment";
+    QByteArray parameters;
+    parameters.append("text="+comment);
+    QString a = oa->getUrl("checkins/"+checkinId+"/addcomment");
+    QString result = doPost(a,parameters);
+
+    QScriptValue sc;
+    QScriptEngine engine;
+    qDebug() << result;
+    sc = engine.evaluate("(" + result + ")");
+
+    if(sc.property("meta").property("code").toNumber()!=200)
+    {
+        qDebug() << "Error occured";
+        return false;
+    }
+    return true;
+}
+
 
