@@ -126,6 +126,8 @@ public:
     f_user getUser(QString id = "self");
     QList<f_tip> getNearbyTips(QString ll);
     f_tip addTip(QString venueId, QString tip, QString link);
+    bool markAs(QString venueId, QString problem);
+    bool addCheckinComment(QString checkinId, QString comment);
 signals:
     void venueReady(f_venue);
 };
