@@ -7,6 +7,7 @@
 #include "venuedetails.h"
 #include <QModelIndex>
 #include "imagecache.h"
+#include "addvenueform.h"
 
 QTM_USE_NAMESPACE
 
@@ -30,9 +31,13 @@ private:
     VenueDetails * vd;
     ImageCache * ic;
     void parseAndShowResult();
+    AddVenueForm * avf;
+
+public slots:
+    void showDetailsForm(f_venue venue);
 
 private slots:
-    void on_listWidget_clicked(QModelIndex index);
+    void on_twNearby_clicked(QModelIndex index);
     void on_pbNearby_clicked();
     void on_pbSearch_clicked();
 };
