@@ -2,6 +2,7 @@
 #include "ui_venuedetails.h"
 #include "foursquarecomm.h"
 #include <QDebug>
+#include <QMaemo5InformationBox>
 
 VenueDetails::VenueDetails(QWidget *parent) :
     QWidget(parent),
@@ -21,6 +22,18 @@ VenueDetails::VenueDetails(QWidget *parent) :
 
     fsc = FoursquareComm::instance();
     ic = new ImageCache(this);
+
+    m = new QMenu(ui->pbMark);
+    QAction* aMislocated = new QAction("Mislocated", this);
+    QAction* aClosed = new QAction("Closed", this);
+    QAction* aDuplicate = new QAction("Duplicate", this);
+    m->addAction(aMislocated);
+    m->addAction(aClosed);
+    m->addAction(aDuplicate);
+    connect(aMislocated,SIGNAL(triggered()),this,SLOT(mislocated_clicked()));
+    connect(aClosed,SIGNAL(triggered()),this,SLOT(closed_clicked()));
+    connect(aDuplicate,SIGNAL(triggered()),this,SLOT(duplicate_clicked()));
+
 }
 
 VenueDetails::~VenueDetails()
@@ -102,3 +115,30 @@ void VenueDetails::venueIsReady()
     this->setVenue(future->result());
     qDebug() << "READY VenueDetails::venueIsReady DONE";
 }
+
+void VenueDetails::on_pbMark_clicked()
+{
+    m->exec(ui->pbMark->pos());
+}
+void VenueDetails::mislocated_clicked()
+{
+    doMark("mislocated");
+}
+void VenueDetails::duplicate_clicked()
+{
+    doMark("duplicate");
+}
+void VenueDetails::closed_clicked()
+{
+   doMark("closed");
+}
+
+void VenueDetails::doMark(QString markAs)
+{
+    if(fsc->markAs(venue.id,markAs))
+    {
+        QMaemo5InformationBox::information(this, "<p>Venue "+venue.name+" flagged as "+markAs+".</p>", QMaemo5InformationBox::DefaultTimeout);
+    } else {
+        QMaemo5InformationBox::information(this, "<p>WARNING: Could not flag "+venue.name+" as "+markAs+".</p>", QMaemo5InformationBox::DefaultTimeout);
+    }
+}
